# PyFBA/util
A directory of utility scripts and files used by and/or with the PyFBA codebase.

### full_roles_ss.tsv
Compilation of the SEED subsystem classes and funcitonal roles. Data extracted using the SEED API on 08 December, 2016.

__Columns__

1. Functional role
2. Category
3. Subcategory
4. Subsystem
